<?php

/**
 * @file
 * Configuration form for Acobot settings.
 */

/**
 * Settings form.
 */
function acobot_admin_settings_form($form_state) {
  $form = array();

  $form['acobot_token'] = array(
    '#type' => 'textfield',
    '#required' => TRUE,
    '#default_value' => variable_get('acobot_token', ''),
    '#title' => t('Installation Key'),
    '#description' => t('To get your installation key, log in to your Acobot
                        account and choose "My web - Installation."
                        <a href="@acobot-register" target="_blank">Sign up</a> if you haven\'t.',
                        array('@acobot-register' => 'http://acobot.com/user/register')),
  );

  // Page specific visibility configurations.
  $form['page_vis_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Page specific visibility settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $access = user_access('use php code for acobot visibility');
  $visibility = variable_get('acobot_visibility', 0);
  $pages = variable_get('acobot_pages', ACOBOT_PAGES);

  if ($visibility == 2 && !$access) {
    $form['page_vis_settings'] = array();
    $form['page_vis_settings']['visibility'] = array('#type' => 'value', '#value' => 2);
    $form['page_vis_settings']['pages'] = array('#type' => 'value', '#value' => $pages);
  }
  else {
    $options = array(t('Add to every page except the listed pages.'), t('Add to the listed pages only.'));
    $description = t("Enter one page per line as Drupal paths.
                     The '*' character is a wildcard. Example paths are
                     %blog for the blog page and %blog-wildcard for every
                     personal blog. %front is the front page.",
                     array('%blog' => 'blog', '%blog-wildcard' => 'blog/*', '%front' => '<front>'));

    if ($access) {
      $options[] = t('Add if the following PHP code returns <code>TRUE</code> (PHP-mode, experts only).');
      $description .= ' ' . t('If the PHP-mode is chosen, enter PHP code
                             between %php. Note that executing incorrect
                             PHP-code can break your Drupal site.',
                             array('%php' => '<?php ?>'));
    }
    $form['page_vis_settings']['acobot_visibility'] = array(
      '#type' => 'radios',
      '#title' => t('Add chat box to specific pages'),
      '#options' => $options,
      '#default_value' => $visibility,
    );
    $form['page_vis_settings']['acobot_pages'] = array(
      '#type' => 'textarea',
      '#title' => t('Pages'),
      '#default_value' => $pages,
      '#description' => $description,
      '#wysiwyg' => FALSE,
      '#rows' => 10,
    );
  }

  // Render the role overview.
  $form['role_vis_settings'] = array(
    '#type' => 'fieldset',
    '#title' => t('Role specific visibility settings'),
    '#collapsible' => TRUE,
    '#collapsed' => TRUE,
  );

  $form['role_vis_settings']['acobot_visibility_roles'] = array(
    '#type' => 'radios',
    '#title' => t('Add chat box for specific roles'),
    '#options' => array(
      t('Selected roles only'),
      t('Every role except the selected ones'),
    ),
    '#default_value' => variable_get('acobot_visibility_roles', 0),
  );

  $roles = user_roles();
  $role_options = array();
  foreach ($roles as $rid => $name) {
    $role_options[$rid] = $name;
  }
  $form['role_vis_settings']['acobot_roles'] = array(
    '#type' => 'checkboxes',
    '#title' => t('Roles'),
    '#default_value' => variable_get('acobot_roles', array()),
    '#options' => $role_options,
    '#description' => t('If none of the roles are selected, all users will
                        receive the chat box. If a user has any of the roles
                        checked, that user will receive the
                        chat box (or excluded, depending on the setting above).'),
  );

  return system_settings_form($form);
}
